summaryrefslogtreecommitdiff
path: root/src/char/int_homun.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/char/int_homun.c')
-rw-r--r--src/char/int_homun.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/char/int_homun.c b/src/char/int_homun.c
index 795a6b927..acde9eb38 100644
--- a/src/char/int_homun.c
+++ b/src/char/int_homun.c
@@ -248,9 +248,9 @@ bool mapif_homunculus_rename(char *name)
{
int i;
// Check Authorised letters/symbols in the name of the homun
if( char_name_option == 1 )
- {// only letters/symbols in char_name_letters are authorised
+ {// only letters/symbols in char_name_letters are authorized
for( i = 0; i < NAME_LENGTH && name[i]; i++ )
if( strchr(char_name_letters, name[i]) == NULL )
return false;
@@ -248,9 +248,9 @@ bool mapif_homunculus_rename(char *name)
{
int i;
- // Check Authorised letters/symbols in the name of the homun
+ // Check Authorized letters/symbols in the name of the homun
if( char_name_option == 1 )